# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mailslurp_client.api_client import ApiClient
from mailslurp_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class GuestPortalControllerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_guest_portal(self, create_portal_options, **kwargs):  # noqa: E501
        """Create a portal page for your customers or clients to log into email accounts and view emails.  # noqa: E501

        Create a guest login page for customers or clients to access assigned email addresses  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_guest_portal(create_portal_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatePortalOptions create_portal_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GuestPortalDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_guest_portal_with_http_info(create_portal_options, **kwargs)  # noqa: E501

    def create_guest_portal_with_http_info(self, create_portal_options, **kwargs):  # noqa: E501
        """Create a portal page for your customers or clients to log into email accounts and view emails.  # noqa: E501

        Create a guest login page for customers or clients to access assigned email addresses  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_guest_portal_with_http_info(create_portal_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatePortalOptions create_portal_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GuestPortalDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_portal_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_guest_portal" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_portal_options' is set
        if self.api_client.client_side_validation and ('create_portal_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_portal_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_portal_options` when calling `create_guest_portal`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_portal_options' in local_var_params:
            body_params = local_var_params['create_portal_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/guest-portal', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GuestPortalDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_guest_portal_user(self, portal_id, create_portal_user_options, **kwargs):  # noqa: E501
        """Create a portal guest user  # noqa: E501

        Add customer to portal  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_guest_portal_user(portal_id, create_portal_user_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str portal_id: (required)
        :param CreatePortalUserOptions create_portal_user_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GuestPortalUserCreateDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_guest_portal_user_with_http_info(portal_id, create_portal_user_options, **kwargs)  # noqa: E501

    def create_guest_portal_user_with_http_info(self, portal_id, create_portal_user_options, **kwargs):  # noqa: E501
        """Create a portal guest user  # noqa: E501

        Add customer to portal  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_guest_portal_user_with_http_info(portal_id, create_portal_user_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str portal_id: (required)
        :param CreatePortalUserOptions create_portal_user_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GuestPortalUserCreateDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'portal_id',
            'create_portal_user_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_guest_portal_user" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'portal_id' is set
        if self.api_client.client_side_validation and ('portal_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['portal_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `portal_id` when calling `create_guest_portal_user`")  # noqa: E501
        # verify the required parameter 'create_portal_user_options' is set
        if self.api_client.client_side_validation and ('create_portal_user_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_portal_user_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_portal_user_options` when calling `create_guest_portal_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'portal_id' in local_var_params:
            path_params['portalId'] = local_var_params['portal_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_portal_user_options' in local_var_params:
            body_params = local_var_params['create_portal_user_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/guest-portal/{portalId}/user', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GuestPortalUserCreateDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_guest_portal_users(self, **kwargs):  # noqa: E501
        """Get all guest users for portal  # noqa: E501

        Get all customers for a portal  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_guest_portal_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str portal_id: Optional portal ID
        :param str search: Optional search term
        :param int page: Optional page index in list pagination
        :param int size: Optional page size in list pagination
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageGuestPortalUsers
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_all_guest_portal_users_with_http_info(**kwargs)  # noqa: E501

    def get_all_guest_portal_users_with_http_info(self, **kwargs):  # noqa: E501
        """Get all guest users for portal  # noqa: E501

        Get all customers for a portal  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_guest_portal_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str portal_id: Optional portal ID
        :param str search: Optional search term
        :param int page: Optional page index in list pagination
        :param int size: Optional page size in list pagination
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageGuestPortalUsers, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'portal_id',
            'search',
            'page',
            'size',
            'sort',
            'since',
            'before'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_guest_portal_users" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'portal_id' in local_var_params and local_var_params['portal_id'] is not None:  # noqa: E501
            query_params.append(('portalId', local_var_params['portal_id']))  # noqa: E501
        if 'search' in local_var_params and local_var_params['search'] is not None:  # noqa: E501
            query_params.append(('search', local_var_params['search']))  # noqa: E501
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/guest-portal/user', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageGuestPortalUsers',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_guest_portal(self, portal_id, **kwargs):  # noqa: E501
        """Get a client email portal  # noqa: E501

        Fetch a customer guest portal  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_guest_portal(portal_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str portal_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GuestPortalDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_guest_portal_with_http_info(portal_id, **kwargs)  # noqa: E501

    def get_guest_portal_with_http_info(self, portal_id, **kwargs):  # noqa: E501
        """Get a client email portal  # noqa: E501

        Fetch a customer guest portal  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_guest_portal_with_http_info(portal_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str portal_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GuestPortalDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'portal_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_guest_portal" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'portal_id' is set
        if self.api_client.client_side_validation and ('portal_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['portal_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `portal_id` when calling `get_guest_portal`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'portal_id' in local_var_params:
            path_params['portalId'] = local_var_params['portal_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/guest-portal/{portalId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GuestPortalDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_guest_portal_user(self, portal_id, guest_id, **kwargs):  # noqa: E501
        """Get guest user for portal  # noqa: E501

        Get customer for portal  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_guest_portal_user(portal_id, guest_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str portal_id: (required)
        :param str guest_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GuestPortalUserDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_guest_portal_user_with_http_info(portal_id, guest_id, **kwargs)  # noqa: E501

    def get_guest_portal_user_with_http_info(self, portal_id, guest_id, **kwargs):  # noqa: E501
        """Get guest user for portal  # noqa: E501

        Get customer for portal  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_guest_portal_user_with_http_info(portal_id, guest_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str portal_id: (required)
        :param str guest_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GuestPortalUserDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'portal_id',
            'guest_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_guest_portal_user" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'portal_id' is set
        if self.api_client.client_side_validation and ('portal_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['portal_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `portal_id` when calling `get_guest_portal_user`")  # noqa: E501
        # verify the required parameter 'guest_id' is set
        if self.api_client.client_side_validation and ('guest_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['guest_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `guest_id` when calling `get_guest_portal_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'portal_id' in local_var_params:
            path_params['portalId'] = local_var_params['portal_id']  # noqa: E501
        if 'guest_id' in local_var_params:
            path_params['guestId'] = local_var_params['guest_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/guest-portal/{portalId}/user/{guestId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GuestPortalUserDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_guest_portal_user_by_id(self, guest_id, **kwargs):  # noqa: E501
        """Get guest user  # noqa: E501

        Get customer by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_guest_portal_user_by_id(guest_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str guest_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GuestPortalUserDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_guest_portal_user_by_id_with_http_info(guest_id, **kwargs)  # noqa: E501

    def get_guest_portal_user_by_id_with_http_info(self, guest_id, **kwargs):  # noqa: E501
        """Get guest user  # noqa: E501

        Get customer by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_guest_portal_user_by_id_with_http_info(guest_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str guest_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GuestPortalUserDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'guest_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_guest_portal_user_by_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'guest_id' is set
        if self.api_client.client_side_validation and ('guest_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['guest_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `guest_id` when calling `get_guest_portal_user_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'guest_id' in local_var_params:
            path_params['guestId'] = local_var_params['guest_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/guest-portal/user/{guestId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GuestPortalUserDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_guest_portal_users(self, portal_id, **kwargs):  # noqa: E501
        """Get all guest users for portal  # noqa: E501

        Get customers for a portal  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_guest_portal_users(portal_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str portal_id: (required)
        :param str search: Optional search term
        :param int page: Optional page index in list pagination
        :param int size: Optional page size in list pagination
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageGuestPortalUsers
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_guest_portal_users_with_http_info(portal_id, **kwargs)  # noqa: E501

    def get_guest_portal_users_with_http_info(self, portal_id, **kwargs):  # noqa: E501
        """Get all guest users for portal  # noqa: E501

        Get customers for a portal  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_guest_portal_users_with_http_info(portal_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str portal_id: (required)
        :param str search: Optional search term
        :param int page: Optional page index in list pagination
        :param int size: Optional page size in list pagination
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageGuestPortalUsers, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'portal_id',
            'search',
            'page',
            'size',
            'sort',
            'since',
            'before'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_guest_portal_users" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'portal_id' is set
        if self.api_client.client_side_validation and ('portal_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['portal_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `portal_id` when calling `get_guest_portal_users`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'portal_id' in local_var_params:
            path_params['portalId'] = local_var_params['portal_id']  # noqa: E501

        query_params = []
        if 'search' in local_var_params and local_var_params['search'] is not None:  # noqa: E501
            query_params.append(('search', local_var_params['search']))  # noqa: E501
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/guest-portal/{portalId}/user', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageGuestPortalUsers',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_guest_portals(self, **kwargs):  # noqa: E501
        """Get guest portals  # noqa: E501

        Get portals  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_guest_portals(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[GuestPortalDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_guest_portals_with_http_info(**kwargs)  # noqa: E501

    def get_guest_portals_with_http_info(self, **kwargs):  # noqa: E501
        """Get guest portals  # noqa: E501

        Get portals  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_guest_portals_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[GuestPortalDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_guest_portals" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/guest-portal', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GuestPortalDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneNumberLineTypeLookupDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'phone_number': 'str',
        'national_format': 'str',
        'country_code': 'str',
        'country_prefix': 'str',
        'is_valid': 'bool',
        'validation_errors': 'list[str]',
        'line_type_intelligence': 'PhoneNumberLineTypeIntelligenceDto',
        'mailslurp_phone_number': 'bool'
    }

    attribute_map = {
        'phone_number': 'phoneNumber',
        'national_format': 'nationalFormat',
        'country_code': 'countryCode',
        'country_prefix': 'countryPrefix',
        'is_valid': 'isValid',
        'validation_errors': 'validationErrors',
        'line_type_intelligence': 'lineTypeIntelligence',
        'mailslurp_phone_number': 'mailslurpPhoneNumber'
    }

    def __init__(self, phone_number=None, national_format=None, country_code=None, country_prefix=None, is_valid=None, validation_errors=None, line_type_intelligence=None, mailslurp_phone_number=None, local_vars_configuration=None):  # noqa: E501
        """PhoneNumberLineTypeLookupDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._phone_number = None
        self._national_format = None
        self._country_code = None
        self._country_prefix = None
        self._is_valid = None
        self._validation_errors = None
        self._line_type_intelligence = None
        self._mailslurp_phone_number = None
        self.discriminator = None

        self.phone_number = phone_number
        if national_format is not None:
            self.national_format = national_format
        if country_code is not None:
            self.country_code = country_code
        if country_prefix is not None:
            self.country_prefix = country_prefix
        self.is_valid = is_valid
        if validation_errors is not None:
            self.validation_errors = validation_errors
        if line_type_intelligence is not None:
            self.line_type_intelligence = line_type_intelligence
        self.mailslurp_phone_number = mailslurp_phone_number

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneNumberLineTypeLookupDto.  # noqa: E501


        :return: The phone_number of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneNumberLineTypeLookupDto.


        :param phone_number: The phone_number of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def national_format(self):
        """Gets the national_format of this PhoneNumberLineTypeLookupDto.  # noqa: E501


        :return: The national_format of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :rtype: str
        """
        return self._national_format

    @national_format.setter
    def national_format(self, national_format):
        """Sets the national_format of this PhoneNumberLineTypeLookupDto.


        :param national_format: The national_format of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :type: str
        """

        self._national_format = national_format

    @property
    def country_code(self):
        """Gets the country_code of this PhoneNumberLineTypeLookupDto.  # noqa: E501


        :return: The country_code of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this PhoneNumberLineTypeLookupDto.


        :param country_code: The country_code of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def country_prefix(self):
        """Gets the country_prefix of this PhoneNumberLineTypeLookupDto.  # noqa: E501


        :return: The country_prefix of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :rtype: str
        """
        return self._country_prefix

    @country_prefix.setter
    def country_prefix(self, country_prefix):
        """Sets the country_prefix of this PhoneNumberLineTypeLookupDto.


        :param country_prefix: The country_prefix of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :type: str
        """

        self._country_prefix = country_prefix

    @property
    def is_valid(self):
        """Gets the is_valid of this PhoneNumberLineTypeLookupDto.  # noqa: E501


        :return: The is_valid of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this PhoneNumberLineTypeLookupDto.


        :param is_valid: The is_valid of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_valid is None:  # noqa: E501
            raise ValueError("Invalid value for `is_valid`, must not be `None`")  # noqa: E501

        self._is_valid = is_valid

    @property
    def validation_errors(self):
        """Gets the validation_errors of this PhoneNumberLineTypeLookupDto.  # noqa: E501


        :return: The validation_errors of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this PhoneNumberLineTypeLookupDto.


        :param validation_errors: The validation_errors of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :type: list[str]
        """

        self._validation_errors = validation_errors

    @property
    def line_type_intelligence(self):
        """Gets the line_type_intelligence of this PhoneNumberLineTypeLookupDto.  # noqa: E501


        :return: The line_type_intelligence of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :rtype: PhoneNumberLineTypeIntelligenceDto
        """
        return self._line_type_intelligence

    @line_type_intelligence.setter
    def line_type_intelligence(self, line_type_intelligence):
        """Sets the line_type_intelligence of this PhoneNumberLineTypeLookupDto.


        :param line_type_intelligence: The line_type_intelligence of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :type: PhoneNumberLineTypeIntelligenceDto
        """

        self._line_type_intelligence = line_type_intelligence

    @property
    def mailslurp_phone_number(self):
        """Gets the mailslurp_phone_number of this PhoneNumberLineTypeLookupDto.  # noqa: E501


        :return: The mailslurp_phone_number of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :rtype: bool
        """
        return self._mailslurp_phone_number

    @mailslurp_phone_number.setter
    def mailslurp_phone_number(self, mailslurp_phone_number):
        """Sets the mailslurp_phone_number of this PhoneNumberLineTypeLookupDto.


        :param mailslurp_phone_number: The mailslurp_phone_number of this PhoneNumberLineTypeLookupDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and mailslurp_phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `mailslurp_phone_number`, must not be `None`")  # noqa: E501

        self._mailslurp_phone_number = mailslurp_phone_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneNumberLineTypeLookupDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneNumberLineTypeLookupDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateDomainOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'description': 'str',
        'created_catch_all_inbox': 'bool',
        'domain_type': 'str'
    }

    attribute_map = {
        'domain': 'domain',
        'description': 'description',
        'created_catch_all_inbox': 'createdCatchAllInbox',
        'domain_type': 'domainType'
    }

    def __init__(self, domain=None, description=None, created_catch_all_inbox=None, domain_type=None, local_vars_configuration=None):  # noqa: E501
        """CreateDomainOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._description = None
        self._created_catch_all_inbox = None
        self._domain_type = None
        self.discriminator = None

        self.domain = domain
        self.description = description
        self.created_catch_all_inbox = created_catch_all_inbox
        self.domain_type = domain_type

    @property
    def domain(self):
        """Gets the domain of this CreateDomainOptions.  # noqa: E501

        The top level domain you wish to use with MailSlurp. Do not specify subdomain just the top level. So `test.com` covers all subdomains such as `mail.test.com`. Don't include a protocol such as `http://`. Once added you must complete the verification steps by adding the returned records to your domain.  # noqa: E501

        :return: The domain of this CreateDomainOptions.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this CreateDomainOptions.

        The top level domain you wish to use with MailSlurp. Do not specify subdomain just the top level. So `test.com` covers all subdomains such as `mail.test.com`. Don't include a protocol such as `http://`. Once added you must complete the verification steps by adding the returned records to your domain.  # noqa: E501

        :param domain: The domain of this CreateDomainOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                domain is not None and len(domain) < 1):
            raise ValueError("Invalid value for `domain`, length must be greater than or equal to `1`")  # noqa: E501

        self._domain = domain

    @property
    def description(self):
        """Gets the description of this CreateDomainOptions.  # noqa: E501

        Optional description of the domain.  # noqa: E501

        :return: The description of this CreateDomainOptions.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateDomainOptions.

        Optional description of the domain.  # noqa: E501

        :param description: The description of this CreateDomainOptions.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def created_catch_all_inbox(self):
        """Gets the created_catch_all_inbox of this CreateDomainOptions.  # noqa: E501

        Whether to create a catch all inbox for the domain. Any email sent to an address using your domain that cannot be matched to an existing inbox you created with the domain will be routed to the created catch all inbox. You can access emails using the regular methods on this inbox ID.  # noqa: E501

        :return: The created_catch_all_inbox of this CreateDomainOptions.  # noqa: E501
        :rtype: bool
        """
        return self._created_catch_all_inbox

    @created_catch_all_inbox.setter
    def created_catch_all_inbox(self, created_catch_all_inbox):
        """Sets the created_catch_all_inbox of this CreateDomainOptions.

        Whether to create a catch all inbox for the domain. Any email sent to an address using your domain that cannot be matched to an existing inbox you created with the domain will be routed to the created catch all inbox. You can access emails using the regular methods on this inbox ID.  # noqa: E501

        :param created_catch_all_inbox: The created_catch_all_inbox of this CreateDomainOptions.  # noqa: E501
        :type: bool
        """

        self._created_catch_all_inbox = created_catch_all_inbox

    @property
    def domain_type(self):
        """Gets the domain_type of this CreateDomainOptions.  # noqa: E501

        Type of domain. Dictates type of inbox that can be created with domain. HTTP means inboxes are processed using SES while SMTP inboxes use a custom SMTP mail server. SMTP does not support sending so use HTTP for sending emails.  # noqa: E501

        :return: The domain_type of this CreateDomainOptions.  # noqa: E501
        :rtype: str
        """
        return self._domain_type

    @domain_type.setter
    def domain_type(self, domain_type):
        """Sets the domain_type of this CreateDomainOptions.

        Type of domain. Dictates type of inbox that can be created with domain. HTTP means inboxes are processed using SES while SMTP inboxes use a custom SMTP mail server. SMTP does not support sending so use HTTP for sending emails.  # noqa: E501

        :param domain_type: The domain_type of this CreateDomainOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"HTTP_INBOX", "SMTP_DOMAIN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and domain_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `domain_type` ({0}), must be one of {1}"  # noqa: E501
                .format(domain_type, allowed_values)
            )

        self._domain_type = domain_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDomainOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDomainOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CampaignProbeSeriesDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'probe_id': 'str',
        'since': 'datetime',
        'before': 'datetime',
        'bucket': 'str',
        'points': 'list[CampaignProbeSeriesPointDto]'
    }

    attribute_map = {
        'probe_id': 'probeId',
        'since': 'since',
        'before': 'before',
        'bucket': 'bucket',
        'points': 'points'
    }

    def __init__(self, probe_id=None, since=None, before=None, bucket=None, points=None, local_vars_configuration=None):  # noqa: E501
        """CampaignProbeSeriesDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._probe_id = None
        self._since = None
        self._before = None
        self._bucket = None
        self._points = None
        self.discriminator = None

        self.probe_id = probe_id
        self.since = since
        self.before = before
        self.bucket = bucket
        self.points = points

    @property
    def probe_id(self):
        """Gets the probe_id of this CampaignProbeSeriesDto.  # noqa: E501


        :return: The probe_id of this CampaignProbeSeriesDto.  # noqa: E501
        :rtype: str
        """
        return self._probe_id

    @probe_id.setter
    def probe_id(self, probe_id):
        """Sets the probe_id of this CampaignProbeSeriesDto.


        :param probe_id: The probe_id of this CampaignProbeSeriesDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and probe_id is None:  # noqa: E501
            raise ValueError("Invalid value for `probe_id`, must not be `None`")  # noqa: E501

        self._probe_id = probe_id

    @property
    def since(self):
        """Gets the since of this CampaignProbeSeriesDto.  # noqa: E501


        :return: The since of this CampaignProbeSeriesDto.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this CampaignProbeSeriesDto.


        :param since: The since of this CampaignProbeSeriesDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and since is None:  # noqa: E501
            raise ValueError("Invalid value for `since`, must not be `None`")  # noqa: E501

        self._since = since

    @property
    def before(self):
        """Gets the before of this CampaignProbeSeriesDto.  # noqa: E501


        :return: The before of this CampaignProbeSeriesDto.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this CampaignProbeSeriesDto.


        :param before: The before of this CampaignProbeSeriesDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and before is None:  # noqa: E501
            raise ValueError("Invalid value for `before`, must not be `None`")  # noqa: E501

        self._before = before

    @property
    def bucket(self):
        """Gets the bucket of this CampaignProbeSeriesDto.  # noqa: E501


        :return: The bucket of this CampaignProbeSeriesDto.  # noqa: E501
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this CampaignProbeSeriesDto.


        :param bucket: The bucket of this CampaignProbeSeriesDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and bucket is None:  # noqa: E501
            raise ValueError("Invalid value for `bucket`, must not be `None`")  # noqa: E501
        allowed_values = ["HOUR", "DAY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and bucket not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `bucket` ({0}), must be one of {1}"  # noqa: E501
                .format(bucket, allowed_values)
            )

        self._bucket = bucket

    @property
    def points(self):
        """Gets the points of this CampaignProbeSeriesDto.  # noqa: E501


        :return: The points of this CampaignProbeSeriesDto.  # noqa: E501
        :rtype: list[CampaignProbeSeriesPointDto]
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this CampaignProbeSeriesDto.


        :param points: The points of this CampaignProbeSeriesDto.  # noqa: E501
        :type: list[CampaignProbeSeriesPointDto]
        """
        if self.local_vars_configuration.client_side_validation and points is None:  # noqa: E501
            raise ValueError("Invalid value for `points`, must not be `None`")  # noqa: E501

        self._points = points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignProbeSeriesDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignProbeSeriesDto):
            return True

        return self.to_dict() != other.to_dict()



from setuptools import setup, find_packages 

setup(
    name="mailslurp-client",
    version="17.4.0",
    description="Official MailSlurp Python SDK Email API",
    author="MailSlurp",
    author_email="contact@mailslurp.dev",
    url="https://www.mailslurp.com/python",
    keywords=["MailSlurp", "Email", "SMTP", "Mailer", "MailSlurp API", "Test"],
    install_requires=["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"],
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""
# MailSlurp Python Client

> Create real email addresses on demand. Send and receive emails and attachments from code and tests using Python.

MailSlurp is an email API service that lets you create real email addresses in code. You can then send and receive emails and attachments in Python applications and tests.

## Video tutorial

[![Python email tutorial](https://www.mailslurp.com/video-thumbnails/python-tutorial.jpeg)](https://youtu.be/tcLJ3xX-H88)

## Quick links

- [API documentation](https://docs.mailslurp.com/api/)
- [Method Documentation](https://python.mailslurp.com/)
- [PyPI Package](https://pypi.org/project/mailslurp-client/)
- [Github Source](https://github.com/mailslurp/mailslurp-client-python)
- [Send email using SMTP in Python](https://www.mailslurp.com/smtp/python-send-email-smtp/)
- [SMTP access details](https://www.mailslurp.com/guides/smtp-imap/)

## Get started

This section describes how to get up and running with the Python client.

See the [examples page](https://www.mailslurp.com/examples/) for more examples and use with common frameworks such as Django, Flask and Pytest.

See the method documentation for a [list of all functions](https://python.mailslurp.com/) or jump to common controllers below:

- [InboxController](https://python.mailslurp.com/api/inbox_controller_api.html)
- [EmailController](https://python.mailslurp.com/api/email_controller_api.html)
- [SMSController](https://python.mailslurp.com/api/sms_controller_api.html)
- [WaitForController](https://python.mailslurp.com/api/wait_for_controller_api.html)

### Create API Key

First you'll need an API Key. [Create a free account](https://app.mailslurp.com) and copy the key from your dashboard.

### Install package

MailSlurp has an official PyPI package called `mailslurp-client`. It supports Python version 2 and 3.

```bash
pip install mailslurp-client
```

On some systems you may need to install `distutils`. If you encounter a `CERTIFICATE_VERIFY_VALID` error you can install `certifi` and `certifi-win32` for Windows:

```bash
pip install python-certifi-win32
```

### Configure

Once installed you can import `mailslurp_client` and create a [configuration](https://python.mailslurp.com/configuration.html) with your [API Key](https://app.mailslurp.com).

```python
import mailslurp_client

configuration = mailslurp_client.Configuration()
configuration.api_key["x-api-key"] = YOUR_API_KEY
```

Then you can create API controller instances using the configuration:

```python
with mailslurp_client.ApiClient(configuration) as api_client:
    api_instance = mailslurp_client.InboxControllerApi(api_client)
    
```

See the [controllers overview](https://python.mailslurp.com/api/index.html) for all API methods.

## Email usage examples

MailSlurp can be used to create email addresses than can send and receive real emails, SMS, and attachments in Python. 

### Create an email address
Create an inbox using the inbox controller:

```python
inbox_controller = mailslurp_client.InboxControllerApi(api_client)
inbox = inbox_controller.create_inbox_with_defaults()
self.assertTrue("@mailslurp" in inbox.email_address)
```

You can pass options using the `CreateInboxOptions` class:

```python
options = mailslurp_client.CreateInboxDto()
options.name = "Test inbox"
options.inbox_type = "SMTP_INBOX"
inbox = inbox_controller.create_inbox_with_options(options)
self.assertTrue("@mailslurp" in inbox.email_address)
```

See the [inbox controller](https://python.mailslurp.com/api/inbox_controller_api.html) for more methods.

### Access inbox using SMTP

```python
smtp_access = inbox_controller.get_imap_smtp_access(inbox_id=inbox.id)
self.assertIsNotNone(smtp_access.secure_smtp_server_host)
```

### Send with SMTP client

```python
# configure smtp client using access details
from smtplib import SMTP

with SMTP(
    host=smtp_access.secure_smtp_server_host,
    port=smtp_access.secure_smtp_server_port,
) as smtp:
    msg = "Subject: Test subject\r\n\r\nThis is the body"
    smtp.login(
        user=smtp_access.secure_smtp_username,
        password=smtp_access.secure_smtp_password,
    )
    smtp.sendmail(
        from_addr=inbox.email_address,
        to_addrs=[inbox.email_address],
        msg=msg,
    )
    smtp.quit()
```

### List inboxes

List inboxes using the [inbox controller](https://python.mailslurp.com/api/inbox_controller_api.html):

```python
inboxes = inbox_controller.get_all_inboxes(page=0)

# pagination properties
self.assertTrue(inboxes.total_pages > 0)
self.assertTrue(inboxes.total_elements > 0)

# view contents
self.assertIsNotNone(inboxes.content[0].email_address)
```

### Get an inbox

```python
inbox = inbox_controller.get_inbox(inbox_id=inbox.id)
self.assertTrue("@mailslurp" in inbox.email_address)

# get by email address
inbox_by_email = inbox_controller.get_inbox_by_email_address(
    inbox.email_address
)
self.assertTrue(inbox_by_email.exists)

# get by name
inbox_by_name = inbox_controller.get_inbox_by_name(inbox.name)
self.assertTrue(inbox_by_name.exists)
```

### Delete an inbox

```python
inbox_controller.delete_inbox(inbox_id=inbox.id)
```

### Upload attachments
To send attachments first upload the attachments as base64 encoded strings and use the returned attachment IDs when sending.

```python
import base64

attachment_controller = mailslurp_client.AttachmentControllerApi(api_client)
options = mailslurp_client.UploadAttachmentOptions(
    filename="test.txt",
    content_type="text/plain",
    base64_contents=base64.b64encode("Hello world".encode("utf-8")).decode(
        "utf-8"
    ),
)
attachment_ids = attachment_controller.upload_attachment(options)
self.assertTrue(len(attachment_ids) == 1)
```

### Send emails
Send emails with the [inbox controller](https://python.mailslurp.com/api/inbox_controller_api.html):

```python
send_options = mailslurp_client.SendEmailOptions(
    to=[recipient.email_address],
    subject="Hello",
    body="Here is your email body",
    attachments=attachment_ids,
)
sent = inbox_controller.send_email_and_confirm(
    inbox_id=inbox.id, send_email_options=send_options
)
self.assertTrue(sent.sent_at is not None)
```

### Receive emails and extract content
Use the [wait for controller](https://python.mailslurp.com/api/wait_for_controller_api.html) to wait for an expected email count to be satisfied and then return those emails.


```python
wait_for_controller = mailslurp_client.WaitForControllerApi(api_client)
email = wait_for_controller.wait_for_latest_email(
    inbox_id=inbox.id, timeout=60_000, unread_only=True
)
self.assertTrue("Hello" in email.subject)
```

### Email content matching

```python
matching_emails = wait_for_controller.wait_for_matching_emails(
    inbox_id=inbox.id,
    timeout=60_000,
    unread_only=False,
    match_options=mailslurp_client.MatchOptions(
        conditions=[
            mailslurp_client.ConditionOption(
                condition="HAS_ATTACHMENTS", value="TRUE"
            )
        ],
        matches=[
            mailslurp_client.MatchOption(
                field="SUBJECT", should="CONTAIN", value="Hello"
            )
        ],
    ),
    count=1,
)
self.assertTrue(len(matching_emails) > 0)
```

### Download attachments

```python
attachment_content = attachment_controller.download_attachment_as_base64_encoded(email.attachments[0])
attachment_metadata = attachment_controller.get_attachment_info(email.attachments[0])
self.assertEqual(attachment_metadata.content_type, "text/plain")
```

### Fetch email by ID

```python
email_controller = mailslurp_client.EmailControllerApi(api_client)
email = email_controller.get_email(email_id=email_id)
self.assertTrue("Hello" in email.subject)
```

### Verify email address

You can verify email addresses with MailSlurp. This will perform SMTP queries for the email address on your behalf.

```python
def test_validate_email(self):
    with mailslurp_client.ApiClient(configuration) as api_client:
        mailserver_controller = mailslurp_client.MailServerControllerApi(api_client)
        verify_options = mailslurp_client.VerifyEmailAddressOptions(email_address="test@gmail.com")
        result = mailserver_controller.verify_email_address(verify_options=verify_options)
        assert result.error is None
        assert result.is_valid is True
```

## SDK Documentation

See the [guides page](https://www.mailslurp.com/guides/) or [the examples](https://www.github.com/mailslurp/examples) or the [Method Documentation](https://python.mailslurp.com/) for full usage.    
    """,
    long_description_content_type="text/markdown"
)



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateDomainMonitorAlertSinkOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'target': 'str',
        'severity_threshold': 'str',
        'enabled': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'target': 'target',
        'severity_threshold': 'severityThreshold',
        'enabled': 'enabled'
    }

    def __init__(self, type=None, target=None, severity_threshold=None, enabled=None, local_vars_configuration=None):  # noqa: E501
        """CreateDomainMonitorAlertSinkOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._target = None
        self._severity_threshold = None
        self._enabled = None
        self.discriminator = None

        self.type = type
        self.target = target
        if severity_threshold is not None:
            self.severity_threshold = severity_threshold
        if enabled is not None:
            self.enabled = enabled

    @property
    def type(self):
        """Gets the type of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501


        :return: The type of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateDomainMonitorAlertSinkOptions.


        :param type: The type of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL", "WEBHOOK", "SLACK", "TEAMS"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def target(self):
        """Gets the target of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501


        :return: The target of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this CreateDomainMonitorAlertSinkOptions.


        :param target: The target of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and target is None:  # noqa: E501
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                target is not None and len(target) < 1):
            raise ValueError("Invalid value for `target`, length must be greater than or equal to `1`")  # noqa: E501

        self._target = target

    @property
    def severity_threshold(self):
        """Gets the severity_threshold of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501


        :return: The severity_threshold of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :rtype: str
        """
        return self._severity_threshold

    @severity_threshold.setter
    def severity_threshold(self, severity_threshold):
        """Sets the severity_threshold of this CreateDomainMonitorAlertSinkOptions.


        :param severity_threshold: The severity_threshold of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["LOW", "MEDIUM", "HIGH", "CRITICAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and severity_threshold not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `severity_threshold` ({0}), must be one of {1}"  # noqa: E501
                .format(severity_threshold, allowed_values)
            )

        self._severity_threshold = severity_threshold

    @property
    def enabled(self):
        """Gets the enabled of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501


        :return: The enabled of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CreateDomainMonitorAlertSinkOptions.


        :param enabled: The enabled of this CreateDomainMonitorAlertSinkOptions.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDomainMonitorAlertSinkOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDomainMonitorAlertSinkOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ExportTransformerResultJobDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'status': 'str',
        'format': 'str',
        'file_name': 'str',
        'download_url': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'format': 'format',
        'file_name': 'fileName',
        'download_url': 'downloadUrl',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, status=None, format=None, file_name=None, download_url=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """ExportTransformerResultJobDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._status = None
        self._format = None
        self._file_name = None
        self._download_url = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.status = status
        self.format = format
        if file_name is not None:
            self.file_name = file_name
        if download_url is not None:
            self.download_url = download_url
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this ExportTransformerResultJobDto.  # noqa: E501


        :return: The id of this ExportTransformerResultJobDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ExportTransformerResultJobDto.


        :param id: The id of this ExportTransformerResultJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def status(self):
        """Gets the status of this ExportTransformerResultJobDto.  # noqa: E501


        :return: The status of this ExportTransformerResultJobDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ExportTransformerResultJobDto.


        :param status: The status of this ExportTransformerResultJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["PENDING", "IN_PROGRESS", "ERROR", "SUCCESS"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def format(self):
        """Gets the format of this ExportTransformerResultJobDto.  # noqa: E501


        :return: The format of this ExportTransformerResultJobDto.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this ExportTransformerResultJobDto.


        :param format: The format of this ExportTransformerResultJobDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and format is None:  # noqa: E501
            raise ValueError("Invalid value for `format`, must not be `None`")  # noqa: E501
        allowed_values = ["CSV", "EXCEL", "XML", "JSON"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and format not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `format` ({0}), must be one of {1}"  # noqa: E501
                .format(format, allowed_values)
            )

        self._format = format

    @property
    def file_name(self):
        """Gets the file_name of this ExportTransformerResultJobDto.  # noqa: E501


        :return: The file_name of this ExportTransformerResultJobDto.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this ExportTransformerResultJobDto.


        :param file_name: The file_name of this ExportTransformerResultJobDto.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def download_url(self):
        """Gets the download_url of this ExportTransformerResultJobDto.  # noqa: E501


        :return: The download_url of this ExportTransformerResultJobDto.  # noqa: E501
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """Sets the download_url of this ExportTransformerResultJobDto.


        :param download_url: The download_url of this ExportTransformerResultJobDto.  # noqa: E501
        :type: str
        """

        self._download_url = download_url

    @property
    def created_at(self):
        """Gets the created_at of this ExportTransformerResultJobDto.  # noqa: E501


        :return: The created_at of this ExportTransformerResultJobDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ExportTransformerResultJobDto.


        :param created_at: The created_at of this ExportTransformerResultJobDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this ExportTransformerResultJobDto.  # noqa: E501


        :return: The updated_at of this ExportTransformerResultJobDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ExportTransformerResultJobDto.


        :param updated_at: The updated_at of this ExportTransformerResultJobDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExportTransformerResultJobDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExportTransformerResultJobDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityAnalyticsSummaryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'total_runs': 'int',
        'complete_runs': 'int',
        'failed_runs': 'int',
        'stopped_runs': 'int',
        'running_runs': 'int',
        'scheduled_runs': 'int',
        'paused_runs': 'int',
        'created_runs': 'int',
        'threshold_configured_runs': 'int',
        'threshold_met_runs': 'int',
        'average_completion_percentage': 'float',
        'average_matched_entities': 'float',
        'average_unmatched_entities': 'float'
    }

    attribute_map = {
        'total_runs': 'totalRuns',
        'complete_runs': 'completeRuns',
        'failed_runs': 'failedRuns',
        'stopped_runs': 'stoppedRuns',
        'running_runs': 'runningRuns',
        'scheduled_runs': 'scheduledRuns',
        'paused_runs': 'pausedRuns',
        'created_runs': 'createdRuns',
        'threshold_configured_runs': 'thresholdConfiguredRuns',
        'threshold_met_runs': 'thresholdMetRuns',
        'average_completion_percentage': 'averageCompletionPercentage',
        'average_matched_entities': 'averageMatchedEntities',
        'average_unmatched_entities': 'averageUnmatchedEntities'
    }

    def __init__(self, total_runs=None, complete_runs=None, failed_runs=None, stopped_runs=None, running_runs=None, scheduled_runs=None, paused_runs=None, created_runs=None, threshold_configured_runs=None, threshold_met_runs=None, average_completion_percentage=None, average_matched_entities=None, average_unmatched_entities=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityAnalyticsSummaryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._total_runs = None
        self._complete_runs = None
        self._failed_runs = None
        self._stopped_runs = None
        self._running_runs = None
        self._scheduled_runs = None
        self._paused_runs = None
        self._created_runs = None
        self._threshold_configured_runs = None
        self._threshold_met_runs = None
        self._average_completion_percentage = None
        self._average_matched_entities = None
        self._average_unmatched_entities = None
        self.discriminator = None

        self.total_runs = total_runs
        self.complete_runs = complete_runs
        self.failed_runs = failed_runs
        self.stopped_runs = stopped_runs
        self.running_runs = running_runs
        self.scheduled_runs = scheduled_runs
        self.paused_runs = paused_runs
        self.created_runs = created_runs
        self.threshold_configured_runs = threshold_configured_runs
        self.threshold_met_runs = threshold_met_runs
        self.average_completion_percentage = average_completion_percentage
        self.average_matched_entities = average_matched_entities
        self.average_unmatched_entities = average_unmatched_entities

    @property
    def total_runs(self):
        """Gets the total_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The total_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._total_runs

    @total_runs.setter
    def total_runs(self, total_runs):
        """Sets the total_runs of this DeliverabilityAnalyticsSummaryDto.


        :param total_runs: The total_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `total_runs`, must not be `None`")  # noqa: E501

        self._total_runs = total_runs

    @property
    def complete_runs(self):
        """Gets the complete_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The complete_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._complete_runs

    @complete_runs.setter
    def complete_runs(self, complete_runs):
        """Sets the complete_runs of this DeliverabilityAnalyticsSummaryDto.


        :param complete_runs: The complete_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and complete_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `complete_runs`, must not be `None`")  # noqa: E501

        self._complete_runs = complete_runs

    @property
    def failed_runs(self):
        """Gets the failed_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The failed_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._failed_runs

    @failed_runs.setter
    def failed_runs(self, failed_runs):
        """Sets the failed_runs of this DeliverabilityAnalyticsSummaryDto.


        :param failed_runs: The failed_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_runs`, must not be `None`")  # noqa: E501

        self._failed_runs = failed_runs

    @property
    def stopped_runs(self):
        """Gets the stopped_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The stopped_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._stopped_runs

    @stopped_runs.setter
    def stopped_runs(self, stopped_runs):
        """Sets the stopped_runs of this DeliverabilityAnalyticsSummaryDto.


        :param stopped_runs: The stopped_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and stopped_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `stopped_runs`, must not be `None`")  # noqa: E501

        self._stopped_runs = stopped_runs

    @property
    def running_runs(self):
        """Gets the running_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The running_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._running_runs

    @running_runs.setter
    def running_runs(self, running_runs):
        """Sets the running_runs of this DeliverabilityAnalyticsSummaryDto.


        :param running_runs: The running_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and running_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `running_runs`, must not be `None`")  # noqa: E501

        self._running_runs = running_runs

    @property
    def scheduled_runs(self):
        """Gets the scheduled_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The scheduled_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._scheduled_runs

    @scheduled_runs.setter
    def scheduled_runs(self, scheduled_runs):
        """Sets the scheduled_runs of this DeliverabilityAnalyticsSummaryDto.


        :param scheduled_runs: The scheduled_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and scheduled_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `scheduled_runs`, must not be `None`")  # noqa: E501

        self._scheduled_runs = scheduled_runs

    @property
    def paused_runs(self):
        """Gets the paused_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The paused_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._paused_runs

    @paused_runs.setter
    def paused_runs(self, paused_runs):
        """Sets the paused_runs of this DeliverabilityAnalyticsSummaryDto.


        :param paused_runs: The paused_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and paused_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `paused_runs`, must not be `None`")  # noqa: E501

        self._paused_runs = paused_runs

    @property
    def created_runs(self):
        """Gets the created_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The created_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._created_runs

    @created_runs.setter
    def created_runs(self, created_runs):
        """Sets the created_runs of this DeliverabilityAnalyticsSummaryDto.


        :param created_runs: The created_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and created_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `created_runs`, must not be `None`")  # noqa: E501

        self._created_runs = created_runs

    @property
    def threshold_configured_runs(self):
        """Gets the threshold_configured_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The threshold_configured_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._threshold_configured_runs

    @threshold_configured_runs.setter
    def threshold_configured_runs(self, threshold_configured_runs):
        """Sets the threshold_configured_runs of this DeliverabilityAnalyticsSummaryDto.


        :param threshold_configured_runs: The threshold_configured_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and threshold_configured_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `threshold_configured_runs`, must not be `None`")  # noqa: E501

        self._threshold_configured_runs = threshold_configured_runs

    @property
    def threshold_met_runs(self):
        """Gets the threshold_met_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The threshold_met_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: int
        """
        return self._threshold_met_runs

    @threshold_met_runs.setter
    def threshold_met_runs(self, threshold_met_runs):
        """Sets the threshold_met_runs of this DeliverabilityAnalyticsSummaryDto.


        :param threshold_met_runs: The threshold_met_runs of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and threshold_met_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `threshold_met_runs`, must not be `None`")  # noqa: E501

        self._threshold_met_runs = threshold_met_runs

    @property
    def average_completion_percentage(self):
        """Gets the average_completion_percentage of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The average_completion_percentage of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: float
        """
        return self._average_completion_percentage

    @average_completion_percentage.setter
    def average_completion_percentage(self, average_completion_percentage):
        """Sets the average_completion_percentage of this DeliverabilityAnalyticsSummaryDto.


        :param average_completion_percentage: The average_completion_percentage of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and average_completion_percentage is None:  # noqa: E501
            raise ValueError("Invalid value for `average_completion_percentage`, must not be `None`")  # noqa: E501

        self._average_completion_percentage = average_completion_percentage

    @property
    def average_matched_entities(self):
        """Gets the average_matched_entities of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The average_matched_entities of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: float
        """
        return self._average_matched_entities

    @average_matched_entities.setter
    def average_matched_entities(self, average_matched_entities):
        """Sets the average_matched_entities of this DeliverabilityAnalyticsSummaryDto.


        :param average_matched_entities: The average_matched_entities of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and average_matched_entities is None:  # noqa: E501
            raise ValueError("Invalid value for `average_matched_entities`, must not be `None`")  # noqa: E501

        self._average_matched_entities = average_matched_entities

    @property
    def average_unmatched_entities(self):
        """Gets the average_unmatched_entities of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501


        :return: The average_unmatched_entities of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :rtype: float
        """
        return self._average_unmatched_entities

    @average_unmatched_entities.setter
    def average_unmatched_entities(self, average_unmatched_entities):
        """Sets the average_unmatched_entities of this DeliverabilityAnalyticsSummaryDto.


        :param average_unmatched_entities: The average_unmatched_entities of this DeliverabilityAnalyticsSummaryDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and average_unmatched_entities is None:  # noqa: E501
            raise ValueError("Invalid value for `average_unmatched_entities`, must not be `None`")  # noqa: E501

        self._average_unmatched_entities = average_unmatched_entities

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityAnalyticsSummaryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityAnalyticsSummaryDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.mfa_controller_api import MFAControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestMFAControllerApi(unittest.TestCase):
    """MFAControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.mfa_controller_api.MFAControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_totp_device_for_base32_secret_key(self):
        """Test case for create_totp_device_for_base32_secret_key

        Create a TOTP device from an base32 secret key  # noqa: E501
        """
        pass

    def test_create_totp_device_for_custom(self):
        """Test case for create_totp_device_for_custom

        Create a TOTP device from custom options  # noqa: E501
        """
        pass

    def test_create_totp_device_for_otp_auth_url(self):
        """Test case for create_totp_device_for_otp_auth_url

        Create a TOTP device from an OTP Auth URL  # noqa: E501
        """
        pass

    def test_get_totp_device(self):
        """Test case for get_totp_device

        Get a TOTP device by ID  # noqa: E501
        """
        pass

    def test_get_totp_device_by(self):
        """Test case for get_totp_device_by

        Get a TOTP device by username, issuer, or name. Returns empty if not found.  # noqa: E501
        """
        pass

    def test_get_totp_device_code(self):
        """Test case for get_totp_device_code

        Get a TOTP device code by device ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class WebhookEmailOpenedPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message_id': 'str',
        'webhook_id': 'str',
        'event_name': 'str',
        'webhook_name': 'str',
        'inbox_id': 'str',
        'pixel_id': 'str',
        'sent_email_id': 'str',
        'recipient': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'message_id': 'messageId',
        'webhook_id': 'webhookId',
        'event_name': 'eventName',
        'webhook_name': 'webhookName',
        'inbox_id': 'inboxId',
        'pixel_id': 'pixelId',
        'sent_email_id': 'sentEmailId',
        'recipient': 'recipient',
        'created_at': 'createdAt'
    }

    def __init__(self, message_id=None, webhook_id=None, event_name=None, webhook_name=None, inbox_id=None, pixel_id=None, sent_email_id=None, recipient=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """WebhookEmailOpenedPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._message_id = None
        self._webhook_id = None
        self._event_name = None
        self._webhook_name = None
        self._inbox_id = None
        self._pixel_id = None
        self._sent_email_id = None
        self._recipient = None
        self._created_at = None
        self.discriminator = None

        self.message_id = message_id
        self.webhook_id = webhook_id
        self.event_name = event_name
        self.webhook_name = webhook_name
        self.inbox_id = inbox_id
        self.pixel_id = pixel_id
        self.sent_email_id = sent_email_id
        self.recipient = recipient
        self.created_at = created_at

    @property
    def message_id(self):
        """Gets the message_id of this WebhookEmailOpenedPayload.  # noqa: E501

        Idempotent message ID. Store this ID locally or in a database to prevent message duplication.  # noqa: E501

        :return: The message_id of this WebhookEmailOpenedPayload.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this WebhookEmailOpenedPayload.

        Idempotent message ID. Store this ID locally or in a database to prevent message duplication.  # noqa: E501

        :param message_id: The message_id of this WebhookEmailOpenedPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message_id is None:  # noqa: E501
            raise ValueError("Invalid value for `message_id`, must not be `None`")  # noqa: E501

        self._message_id = message_id

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookEmailOpenedPayload.  # noqa: E501

        ID of webhook entity being triggered  # noqa: E501

        :return: The webhook_id of this WebhookEmailOpenedPayload.  # noqa: E501
        :rtype: str
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookEmailOpenedPayload.

        ID of webhook entity being triggered  # noqa: E501

        :param webhook_id: The webhook_id of this WebhookEmailOpenedPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and webhook_id is None:  # noqa: E501
            raise ValueError("Invalid value for `webhook_id`, must not be `None`")  # noqa: E501

        self._webhook_id = webhook_id

    @property
    def event_name(self):
        """Gets the event_name of this WebhookEmailOpenedPayload.  # noqa: E501

        Name of the event type webhook is being triggered for.  # noqa: E501

        :return: The event_name of this WebhookEmailOpenedPayload.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this WebhookEmailOpenedPayload.

        Name of the event type webhook is being triggered for.  # noqa: E501

        :param event_name: The event_name of this WebhookEmailOpenedPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_name is None:  # noqa: E501
            raise ValueError("Invalid value for `event_name`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL_RECEIVED", "NEW_AI_TRANSFORM_RESULT", "NEW_EMAIL", "NEW_CONTACT", "NEW_ATTACHMENT", "EMAIL_OPENED", "EMAIL_READ", "DELIVERY_STATUS", "BOUNCE", "BOUNCE_RECIPIENT", "NEW_SMS", "NEW_GUEST_USER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_name not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_name` ({0}), must be one of {1}"  # noqa: E501
                .format(event_name, allowed_values)
            )

        self._event_name = event_name

    @property
    def webhook_name(self):
        """Gets the webhook_name of this WebhookEmailOpenedPayload.  # noqa: E501

        Name of the webhook being triggered  # noqa: E501

        :return: The webhook_name of this WebhookEmailOpenedPayload.  # noqa: E501
        :rtype: str
        """
        return self._webhook_name

    @webhook_name.setter
    def webhook_name(self, webhook_name):
        """Sets the webhook_name of this WebhookEmailOpenedPayload.

        Name of the webhook being triggered  # noqa: E501

        :param webhook_name: The webhook_name of this WebhookEmailOpenedPayload.  # noqa: E501
        :type: str
        """

        self._webhook_name = webhook_name

    @property
    def inbox_id(self):
        """Gets the inbox_id of this WebhookEmailOpenedPayload.  # noqa: E501

        Id of the inbox  # noqa: E501

        :return: The inbox_id of this WebhookEmailOpenedPayload.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this WebhookEmailOpenedPayload.

        Id of the inbox  # noqa: E501

        :param inbox_id: The inbox_id of this WebhookEmailOpenedPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and inbox_id is None:  # noqa: E501
            raise ValueError("Invalid value for `inbox_id`, must not be `None`")  # noqa: E501

        self._inbox_id = inbox_id

    @property
    def pixel_id(self):
        """Gets the pixel_id of this WebhookEmailOpenedPayload.  # noqa: E501

        ID of the tracking pixel  # noqa: E501

        :return: The pixel_id of this WebhookEmailOpenedPayload.  # noqa: E501
        :rtype: str
        """
        return self._pixel_id

    @pixel_id.setter
    def pixel_id(self, pixel_id):
        """Sets the pixel_id of this WebhookEmailOpenedPayload.

        ID of the tracking pixel  # noqa: E501

        :param pixel_id: The pixel_id of this WebhookEmailOpenedPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and pixel_id is None:  # noqa: E501
            raise ValueError("Invalid value for `pixel_id`, must not be `None`")  # noqa: E501

        self._pixel_id = pixel_id

    @property
    def sent_email_id(self):
        """Gets the sent_email_id of this WebhookEmailOpenedPayload.  # noqa: E501

        ID of sent email  # noqa: E501

        :return: The sent_email_id of this WebhookEmailOpenedPayload.  # noqa: E501
        :rtype: str
        """
        return self._sent_email_id

    @sent_email_id.setter
    def sent_email_id(self, sent_email_id):
        """Sets the sent_email_id of this WebhookEmailOpenedPayload.

        ID of sent email  # noqa: E501

        :param sent_email_id: The sent_email_id of this WebhookEmailOpenedPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sent_email_id is None:  # noqa: E501
            raise ValueError("Invalid value for `sent_email_id`, must not be `None`")  # noqa: E501

        self._sent_email_id = sent_email_id

    @property
    def recipient(self):
        """Gets the recipient of this WebhookEmailOpenedPayload.  # noqa: E501

        Email address for the recipient of the tracking pixel  # noqa: E501

        :return: The recipient of this WebhookEmailOpenedPayload.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this WebhookEmailOpenedPayload.

        Email address for the recipient of the tracking pixel  # noqa: E501

        :param recipient: The recipient of this WebhookEmailOpenedPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and recipient is None:  # noqa: E501
            raise ValueError("Invalid value for `recipient`, must not be `None`")  # noqa: E501

        self._recipient = recipient

    @property
    def created_at(self):
        """Gets the created_at of this WebhookEmailOpenedPayload.  # noqa: E501

        Date time of event creation  # noqa: E501

        :return: The created_at of this WebhookEmailOpenedPayload.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this WebhookEmailOpenedPayload.

        Date time of event creation  # noqa: E501

        :param created_at: The created_at of this WebhookEmailOpenedPayload.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookEmailOpenedPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookEmailOpenedPayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneProviderCapabilitiesResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'provider_label': 'str',
        'phone_country': 'str',
        'supported_variants': 'list[str]',
        'warning': 'str'
    }

    attribute_map = {
        'provider_label': 'providerLabel',
        'phone_country': 'phoneCountry',
        'supported_variants': 'supportedVariants',
        'warning': 'warning'
    }

    def __init__(self, provider_label=None, phone_country=None, supported_variants=None, warning=None, local_vars_configuration=None):  # noqa: E501
        """PhoneProviderCapabilitiesResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._provider_label = None
        self._phone_country = None
        self._supported_variants = None
        self._warning = None
        self.discriminator = None

        self.provider_label = provider_label
        self.phone_country = phone_country
        self.supported_variants = supported_variants
        if warning is not None:
            self.warning = warning

    @property
    def provider_label(self):
        """Gets the provider_label of this PhoneProviderCapabilitiesResult.  # noqa: E501


        :return: The provider_label of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :rtype: str
        """
        return self._provider_label

    @provider_label.setter
    def provider_label(self, provider_label):
        """Sets the provider_label of this PhoneProviderCapabilitiesResult.


        :param provider_label: The provider_label of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and provider_label is None:  # noqa: E501
            raise ValueError("Invalid value for `provider_label`, must not be `None`")  # noqa: E501

        self._provider_label = provider_label

    @property
    def phone_country(self):
        """Gets the phone_country of this PhoneProviderCapabilitiesResult.  # noqa: E501


        :return: The phone_country of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhoneProviderCapabilitiesResult.


        :param phone_country: The phone_country of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def supported_variants(self):
        """Gets the supported_variants of this PhoneProviderCapabilitiesResult.  # noqa: E501


        :return: The supported_variants of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._supported_variants

    @supported_variants.setter
    def supported_variants(self, supported_variants):
        """Sets the supported_variants of this PhoneProviderCapabilitiesResult.


        :param supported_variants: The supported_variants of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and supported_variants is None:  # noqa: E501
            raise ValueError("Invalid value for `supported_variants`, must not be `None`")  # noqa: E501

        self._supported_variants = supported_variants

    @property
    def warning(self):
        """Gets the warning of this PhoneProviderCapabilitiesResult.  # noqa: E501


        :return: The warning of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :rtype: str
        """
        return self._warning

    @warning.setter
    def warning(self, warning):
        """Sets the warning of this PhoneProviderCapabilitiesResult.


        :param warning: The warning of this PhoneProviderCapabilitiesResult.  # noqa: E501
        :type: str
        """

        self._warning = warning

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneProviderCapabilitiesResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneProviderCapabilitiesResult):
            return True

        return self.to_dict() != other.to_dict()
